import urllib.request
import urllib.parse

movie_ids = {"The Matrix": "tt0133093",
             "Rick and Morty": "tt2861424"}


IMBD_URL_QUOTE = 'https://www.imdb.com/title/{movie_id}/quotes'
DEFAULT_MAX_QUOTES = 100


def html_from_url(url, params=None):
    if params:
        url += urllib.parse.quote(params)
    res = urllib.request.urlopen(url)
    body = res.read().decode()
    return body



from bs4 import BeautifulSoup
from . import utils


def quotes_from_page_id(page_id, max_quotes=utils.DEFAULT_MAX_QUOTES):
    local_page_url = utils.IMBD_URL_QUOTE.format(movie_id=page_id)
    data = utils.html_from_url(local_page_url)
    html_tree = BeautifulSoup(data, 'html.parser')
    return _extract_quotes(html_tree, max_quotes)


def _extract_quotes(tree, max_quotes):
    dialogs = []
    for element in tree.find_all("div"):
        current_dialog = []
        if element.get("class") is not None and "quote" in element.get("class"):
            current_text = None
            for sub in element.descendants:
                if sub.name == "p":
                    current_text = sub.text
                elif sub.name == "span" and sub.get("class") is not None and "character" in sub.get("class"):
                    current_dialog.append({current_text.replace(sub.string, '')[2:].strip(): sub.string})
            dialogs.append(current_dialog.copy())
        if len(dialogs) >= max_quotes:
            break
    return dialogs



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
  name = 'imbd_quotes',
  packages = ['imbd_quotes'],
  version = '0.1.1',
  description = 'Retrieve quotes from any IMBD page.',
  author = 'Guilhem Bn.',
  author_email = 'buisanguilhem@gmail.com',
  install_requires = ['beautifulsoup4'],
  url = 'https://github.com/guilhembn/python-imbdquotes',
  download_url = 'https://github.com/guilhembn/python-imbdquotes/archive/0.1.1.tar.gz',
  keywords = ['quotes', 'IMBD', 'python', 'api'],
  license = 'MIT',
  classifiers = [
    'Programming Language :: Python :: 3',
    'Programming Language :: Python :: 3.4',
    'License :: OSI Approved :: MIT License'
  ],
)
